@@ -6,11 +6,6 @@ use brunch::{
 	Bench,
 	benches,
 };
-use chrono::{
-	Utc,
-	TimeZone,
-};
-use std::convert::TryFrom;
 use utc2k::{
 	FmtUtc2k,
 	Utc2k,
@@ -26,12 +21,5 @@ benches!(
 		.with(|| FmtUtc2k::try_from("2019-04-10")),
 
 	Bench::new("utc2k::FmtUtc2k", "to_string()")
-		.with(|| FmtUtc2k::from(Utc2k::MAX_UNIXTIME).to_string()),
-
-	Bench::new("chrono::Utc", "to_string()")
-		.with(||
-			Utc.timestamp(Utc2k::MAX_UNIXTIME as i64, 0)
-				.format("%Y-%m-%d %H:%M:%S")
-				.to_string()
-		)
+		.with(|| FmtUtc2k::from(Utc2k::MAX_UNIXTIME).to_string())
 );
